Index Table
===============================================================================

See the API documentation for :py:class:`hipscat_import.index.arguments.IndexArguments`

.. note::

    TODO - write the rest